import os
import subprocess

#
# Determines the DRBD device for the given virtual server and device.
#
def getDrbdDevice(server, device):
    drbdadmfh = os.popen('/sbin/drbdadm sh-dev ' + server + '-' + device, 'r')
    drbddevice = drbdadmfh.readline().rstrip()
    drbdadmfh.close()
    if drbddevice == '' : raise 'Unable to find drbd device for ' + server + '-' + device
    return drbddevice

#
# Determines the DRBD role for the given virtual server and device.
#
def getDrbdRole(server, device):
    drbdadmfh = os.popen('/sbin/drbdadm role ' + server + '-' + device, 'r')
    drbdrole = drbdadmfh.readline().rstrip()
    drbdadmfh.close()
    if drbdrole == '' : raise 'Unable to find drbd role for ' + server + '-' + device
    return drbdrole

#
# Checks that the DRBD role is acceptable for creating the virtual server.
# This is the main protection against split brain, since we now run with
# allow-two-primaries to support live migration.
#
# Returns upon success or raises exception if virtual server should not be created.
#
def checkDrbdRole(server, device):
    role = getDrbdRole(server, device)
    if role not in [ 'Secondary/Secondary', 'Primary/Secondary', 'Primary/Unknown' ] :
        raise 'Avoiding possible split brain for ' + server + '-' + device + ', role = ' + role

#
# Puts a DRBD into the primary state.
# No check is performed to prevent two primaries, see checkDrbdRole above.
#
def setDrbdPrimary(server, device):
    retcode = subprocess.call(
        [
            '/sbin/drbdadm',
            'primary',
            server + '-' + device
        ]
    )
    if retcode != 0 : raise 'Unable to make primary for ' + server + '-' + device

#
# Gets the path of the paravirtualized kernel and its associated ramdisk
#
def getKernel(osname, osversion, kernelversion, kerneltype, rootfstype):
    kernel  = '/etc/xen/kernels/' + osname + '/' + osversion + '/' + kernelversion + '/' + kerneltype + '/' + os.uname()[4] + '/' + 'vmlinuz'
    ramdisk = '/etc/xen/kernels/' + osname + '/' + osversion + '/' + kernelversion + '/' + kerneltype + '/' + os.uname()[4] + '/' + 'initrd-' + rootfstype + '.img'
    return kernel, ramdisk
